pub struct U16PartitionedTableWriter<PartitionWriter: TableWriter + Send> { /* private fields */ }Expand description
Wraps N TableWriter in such a way that they each write to base/0/x.parquet,
…, base/N-1/x.parquet instead of base/x.parquet.
This allows Hive partitioning while writing with multiple threads (x is the
thread id in the example above).
If num_partitions is None, disables partitioning.
Implementations
Sourceimpl<PartitionWriter: TableWriter + Send> U16PartitionedTableWriter<PartitionWriter>
impl<PartitionWriter: TableWriter + Send> U16PartitionedTableWriter<PartitionWriter>
pub fn partitions(&mut self) -> &mut [PartitionWriter]