Utf8PartitionedTableWriter

Struct Utf8PartitionedTableWriter 

pub struct Utf8PartitionedTableWriter<PartitionWriter: TableWriter + Send> { /* private fields */ }
Wraps a set of TableWriter in such a way that they each write to a different base/<partition_key>/x.parquet instead of base/x.parquet, where <partition_key> is a UTF8 column.

This allows Hive partitioning while writing with multiple threads (x is the thread id in the example above).

Implementations

Source

impl<PartitionWriter: TableWriter + Send> Utf8PartitionedTableWriter<PartitionWriter>

pub fn partition( &mut self, partition_key: String, ) -> Result<&mut PartitionWriter>

pub fn partitions(&mut self) -> &mut HashMap<String, PartitionWriter>