pub struct ParquetTableWriterConfig {
pub autoflush_row_group_len: Option<usize>,
pub autoflush_buffer_size: Option<usize>,
}Fields
autoflush_row_group_len: Option<usize>Automatically flushes the builder to disk when its length (in number of rows) reaches the value.
To avoid uneven row group sizes, this value plus the number of values added
to the builder between calls to ParquetTableWriter::builder should be equal to
max_row_group_size
(or a multiple of it).
Defaults to max_row_group_size
if None.
autoflush_buffer_size: Option<usize>Automatically flushes the builder to disk when its size (in number of bytes in the arrays) reaches the value.
Does not automatically flush on size if None